==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/IoT/SetLoggingOptions.pm <==

package Paws::IoT::SetLoggingOptions;
  use Moose;
  has loggingOptionsPayload => (is => 'ro', isa => 'Paws::IoT::LoggingOptionsPayload');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SetLoggingOptions');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/loggingOptions');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::SetLoggingOptions - Arguments for method SetLoggingOptions on Paws::IoT

=head1 DESCRIPTION

This class represents the parameters used for calling the method SetLoggingOptions on the 
AWS IoT service. Use the attributes of this class
as arguments to method SetLoggingOptions.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to SetLoggingOptions.

As an example:

  $service_obj->SetLoggingOptions(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 loggingOptionsPayload => Paws::IoT::LoggingOptionsPayload

  

The logging options payload.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SetLoggingOptions in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/IoT/SetLoggingOptions.pm <==

package Paws::IoT::SetLoggingOptions;
  use Moose;
  has LoggingOptionsPayload => (is => 'ro', isa => 'Paws::IoT::LoggingOptionsPayload');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SetLoggingOptions');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/loggingOptions');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::SetLoggingOptions - Arguments for method SetLoggingOptions on Paws::IoT

=head1 DESCRIPTION

This class represents the parameters used for calling the method SetLoggingOptions on the 
AWS IoT service. Use the attributes of this class
as arguments to method SetLoggingOptions.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to SetLoggingOptions.

As an example:

  $service_obj->SetLoggingOptions(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 LoggingOptionsPayload => L<Paws::IoT::LoggingOptionsPayload>

  The logging options payload.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SetLoggingOptions in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
